@@ -1,17 +1,19 @@
 #' Import Files
-#' 
+#'
 #' Import all R-files in a directory.
-#' 
+#'
 #' @param ... Directory from which to import `.R` or `.r` files.
-#' 
-#' @examples 
-#' \dontrun{import("views")}
-#' 
+#'
+#' @examples
+#' if (interactive()) {
+#'   import("views")
+#' }
+#'
 #' @return Invisibly returns `NULL`.
-#' 
+#'
 #' @export
-import <- function(...){{
-  files <- fs::dir_ls(..., regexp = "\\.R$|\\.r$") 
+import <- function(...) {
+  files <- fs::dir_ls(..., regexp = "\\.R$|\\.r$")
   sapply(files, source)
   invisible()
-}}
\ No newline at end of file
+}
