@@ -197,6 +197,47 @@ Routing <- R6::R6Class(
 
       invisible(self)
     },
+    #' @details PARAM Method
+    #'
+    #' @param name Name of the parameter
+    #' @param handler Function that accepts the request, response, parameter value and the parameter name.
+    #'
+    #' @examples
+    #' app <- Ambiorix$new()
+    #'
+    #' app$get("/", function(req,res){
+    #'  res$send("Hello!")
+    #' })
+    #'
+    #' app$param("person", function(req, res, value, name){
+    #'  if(value == "notWanted"){
+    #'   res$status <- 403L
+    #'   res$send("This is the end.")
+    #'  }
+    #'
+    #'  # continue processing the request...
+    #' })
+    #'
+    #' app$get("/hi/:person", function(req,res){
+    #'  res$sendf("Hi! %s", req$params$person)
+    #' })
+    #' app$get("/info/:person", function(req,res){
+    #'  res$sendf("Here is all your info, %s", req$params$person)
+    #' })
+    #' if(interactive())
+    #'  app$start()
+    param = function(name, handler) {
+      assert_that(not_missing(handler))
+      assert_that(is_param_handler(handler))
+      p <- lapply(name, function(s) {
+        list(
+          handler = handler,
+          params = s
+        )
+      })
+      private$.params <- append(private$.params, p)
+      invisible(self)
+    },
     #' @details Receive Websocket Message
     #' @param name Name of message.
     #' @param handler Function to run when message is received.
@@ -338,6 +379,7 @@ Routing <- R6::R6Class(
           function(route) {
             route$route$as_pattern(parent)
             route$route$decompose(parent)
+            route$route$basepath <- private$.basepath
             route
           }
         )
@@ -355,6 +397,33 @@ Routing <- R6::R6Class(
 
       return(routes)
     },
+    #' @details Get the parameter middlewares
+    #' @param params Existing list of parameter middlewares.
+    #' @param parent Parent path.
+    get_params = function(params = list(), parent = "") {
+      params <- append(
+        params,
+        lapply(
+          private$.params,
+          function(fn) {
+            attr(fn, "basepath") <- private$.basepath
+            return(fn)
+          }
+        )
+      )
+
+      if (!length(private$.routers)) {
+        return(params)
+      }
+
+      parent <- paste0(parent, private$.basepath)
+
+      for (router in private$.routers) {
+        params <- router$get_params(params, parent)
+      }
+
+      return(params)
+    },
     #' @details Get the websocket receivers
     #' @param receivers Existing list of receivers
     get_receivers = function(receivers = list()) {
@@ -443,6 +512,7 @@ Routing <- R6::R6Class(
     .static = list(),
     .receivers = list(),
     .middleware = list(),
+    .params = list(),
     .is_running = FALSE,
     .wss_custom = NULL,
     .routers = list(),
@@ -474,21 +544,6 @@ Routing <- R6::R6Class(
       request <- Request$new(req)
       res <- Response$new()
 
-      if (length(private$.middleware) > 0L) {
-        for (i in seq_along(private$.middleware)) {
-          mid_basepath <- attr(private$.middleware[[i]], "basepath")
-
-          mid_res <- NULL
-          if (grepl(mid_basepath, req$PATH_INFO)) {
-            mid_res <- private$.middleware[[i]](request, res)
-          }
-
-          if (is_response(mid_res)) {
-            return(mid_res)
-          }
-        }
-      }
-
       # loop over routes
       for (i in seq_along(private$.routes)) {
         # if path matches pattern and method
@@ -498,6 +553,8 @@ Routing <- R6::R6Class(
         ) {
           .globals$infoLog$log(req$REQUEST_METHOD, "on", req$PATH_INFO)
 
+          basepath <- private$.routes[[i]]$route$basepath
+
           # parse request
           request$params <- tryCatch(
             set_params(request$PATH_INFO, private$.routes[[i]]$route),
@@ -510,6 +567,52 @@ Routing <- R6::R6Class(
             return(private$.routes[[i]]$error(request, res, request$params))
           }
 
+          # parameter middleware
+
+          if (length(private$.params) > 0L && length(request$params) > 0L) {
+            for (j in seq_along(private$.params)) {
+              param_res <- NULL
+              pn <- private$.params[[j]]$params
+              pv <- request$params[[pn]]
+
+              # if param middleware is on correct router and has a handler for
+              # a request parameter.
+
+              if (
+                identical(attr(private$.params[[j]], "basepath"), basepath) &&
+                  !is.null(pv)
+              ) {
+                param_res <- private$.params[[j]]$handler(
+                  request,
+                  res,
+                  pv,
+                  pn
+                )
+
+                if (is_response(param_res)) {
+                  return(param_res)
+                }
+              }
+            }
+          }
+
+          # Middleware
+
+          if (length(private$.middleware) > 0L) {
+            for (j in seq_along(private$.middleware)) {
+              mid_basepath <- attr(private$.middleware[[j]], "basepath")
+
+              mid_res <- NULL
+              if (grepl(mid_basepath, req$PATH_INFO)) {
+                mid_res <- private$.middleware[[j]](request, res)
+              }
+
+              if (is_response(mid_res)) {
+                return(mid_res)
+              }
+            }
+          }
+
           # get response
           response <- tryCatch(
             private$.routes[[i]]$fun(request, res),
@@ -528,7 +631,10 @@ Routing <- R6::R6Class(
             return(self$error(request, res, response))
           }
 
-          if (inherits(x = response, what = c("promise", "Future"))) {
+          if (
+            inherits(x = response, what = c("promise", "Future")) ||
+              inherits(x = response, what = "mirai")
+          ) {
             return(
               promises::then(
                 response,
