@@ -1,8 +1,8 @@
-library(htmltools);
+library(htmltools)
 
 tags$html(
   tags$title("[% title %]"),
   tags$body(
     p("hello")
   )
-)
\ No newline at end of file
+)
